startPreview method

  1. @override
Future<int> startPreview()
override

Starts the native preview stream.

Returns a Future that completes with the texture id used by a Texture widget to display the feed.

Implementation

@override
Future<int> startPreview() async {
  final int textureId = await methodChannel.invokeMethod('startPreview');
  return textureId;
}